@@ -1,24 +1,9 @@
 /*
-  Copyright (C) 2008-2009 by Eike Hein <hein@kde.org>
+  SPDX-FileCopyrightText: 2008-2009 Eike Hein <hein@kde.org>
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License as
-  published by the Free Software Foundation; either version 2 of
-  the License or (at your option) version 3 or any later version
-  accepted by the membership of KDE e.V. (or its successor appro-
-  ved by the membership of KDE e.V.), which shall act as a proxy
-  defined in Section 14 of version 3 of the license.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program. If not, see https://www.gnu.org/licenses/.
+  SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-
 #include "appearancesettings.h"
 #include "settings.h"
 #include "skinlistdelegate.h"
@@ -30,8 +15,12 @@
 #include <KMessageBox>
 #include <KTar>
 
+#include <knewstuff_version.h>
+#if KNEWSTUFF_VERSION < QT_VERSION_CHECK(5, 78, 0)
 #include <downloaddialog.h>
-#include <downloadmanager.h>
+#else
+#include <QtQuickDialogWrapper>
+#endif
 
 #include <QDir>
 #include <QDirIterator>
@@ -42,7 +31,8 @@
 
 #include <unistd.h>
 
-AppearanceSettings::AppearanceSettings(QWidget* parent) : QWidget(parent)
+AppearanceSettings::AppearanceSettings(QWidget *parent)
+    : QWidget(parent)
 {
     setupUi(this);
 
@@ -56,19 +46,16 @@ AppearanceSettings::AppearanceSettings(QWidget* parent) : QWidget(parent)
     skinList->setModel(m_skins);
     skinList->setItemDelegate(m_skinListDelegate);
 
-    connect(skinList->selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)),
-        this, SLOT(updateSkinSetting()));
-    connect(skinList->selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)),
-        this, SLOT(updateRemoveSkinButton()));
+    connect(skinList->selectionModel(), &QItemSelectionModel::currentChanged, this, &AppearanceSettings::updateSkinSetting);
+    connect(skinList->selectionModel(), &QItemSelectionModel::currentChanged, this, &AppearanceSettings::updateRemoveSkinButton);
     connect(installButton, SIGNAL(clicked()), this, SLOT(installSkin()));
-    connect(removeButton, SIGNAL(clicked()), this, SLOT(removeSelectedSkin()));
+    connect(removeButton, &QAbstractButton::clicked, this, &AppearanceSettings::removeSelectedSkin);
 
     installButton->setIcon(QIcon::fromTheme(QStringLiteral("folder")));
     removeButton->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
     ghnsButton->setIcon(QIcon::fromTheme(QStringLiteral("get-hot-new-stuff")));
 
     m_knsConfigFileName = QLatin1String("yakuake.knsrc");
-    m_knsDownloadManager = new KNSCore::DownloadManager(m_knsConfigFileName);
 
     connect(ghnsButton, &QPushButton::clicked, this, &AppearanceSettings::getNewSkins);
 
@@ -87,7 +74,7 @@ AppearanceSettings::~AppearanceSettings()
 {
 }
 
-void AppearanceSettings::showEvent(QShowEvent* event)
+void AppearanceSettings::showEvent(QShowEvent *event)
 {
     populateSkinList();
 
@@ -105,8 +92,7 @@ void AppearanceSettings::populateSkinList()
     allSkinLocations << QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("/yakuake/skins/"), QStandardPaths::LocateDirectory);
     allSkinLocations << QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("/yakuake/kns_skins/"), QStandardPaths::LocateDirectory);
 
-    Q_FOREACH (const QString& skinLocation, allSkinLocations)
-    {
+    Q_FOREACH (const QString &skinLocation, allSkinLocations) {
         populateSkinList(skinLocation);
     }
 
@@ -115,17 +101,15 @@ void AppearanceSettings::populateSkinList()
     updateRemoveSkinButton();
 }
 
-void AppearanceSettings::populateSkinList(const QString& installLocation)
+void AppearanceSettings::populateSkinList(const QString &installLocation)
 {
     QDirIterator it(installLocation, QDir::Dirs | QDir::NoDotAndDotDot);
 
-    while (it.hasNext())
-    {
-        const QDir& skinDir(it.next());
+    while (it.hasNext()) {
+        const QDir &skinDir(it.next());
 
-        if (skinDir.exists(QStringLiteral("title.skin")) && skinDir.exists(QStringLiteral("tabs.skin")))
-        {
-            QStandardItem* skin = createSkinItem(skinDir.absolutePath());
+        if (skinDir.exists(QStringLiteral("title.skin")) && skinDir.exists(QStringLiteral("tabs.skin"))) {
+            QStandardItem *skin = createSkinItem(skinDir.absolutePath());
 
             if (!skin)
                 continue;
@@ -138,7 +122,7 @@ void AppearanceSettings::populateSkinList(const QString& installLocation)
     }
 }
 
-QStandardItem* AppearanceSettings::createSkinItem(const QString& skinDir)
+QStandardItem *AppearanceSettings::createSkinItem(const QString &skinDir)
 {
     QString skinId = skinDir.section(QLatin1Char('/'), -1, -1);
     QString titleName, tabName, skinName;
@@ -174,7 +158,7 @@ QStandardItem* AppearanceSettings::createSkinItem(const QString& skinDir)
     if (skinAuthor.isEmpty())
         skinAuthor = xi18nc("@item:inlistbox Unknown skin author", "Unknown");
 
-    QStandardItem* skin = new QStandardItem(skinName);
+    QStandardItem *skin = new QStandardItem(skinName);
 
     skin->setData(skinId, SkinId);
     skin->setData(skinDir, SkinDir);
@@ -190,8 +174,7 @@ void AppearanceSettings::updateSkinSetting()
 {
     QString skinId = skinList->currentIndex().data(SkinId).toString();
 
-    if (!skinId.isEmpty())
-    {
+    if (!skinId.isEmpty()) {
         m_selectedSkinId = skinId;
         kcfg_Skin->setText(skinId);
         kcfg_SkinInstalledWithKns->setChecked(skinList->currentIndex().data(SkinInstalledWithKns).toBool());
@@ -202,10 +185,10 @@ void AppearanceSettings::resetSelection()
 {
     m_selectedSkinId = Settings::skin();
 
-    QModelIndexList skins = m_skins->match(m_skins->index(0, 0), SkinId,
-        Settings::skin(), 1, Qt::MatchExactly | Qt::MatchWrap);
+    QModelIndexList skins = m_skins->match(m_skins->index(0, 0), SkinId, Settings::skin(), 1, Qt::MatchExactly | Qt::MatchWrap);
 
-    if (skins.count() > 0) skinList->setCurrentIndex(skins.at(0));
+    if (skins.count() > 0)
+        skinList->setCurrentIndex(skins.at(0));
 }
 
 void AppearanceSettings::installSkin()
@@ -232,8 +215,7 @@ void AppearanceSettings::installSkin()
 
     KIO::CopyJob *job = KIO::copy(skinUrl, QUrl::fromLocalFile(m_installSkinFile.fileName()), KIO::JobFlag::HideProgressInfo | KIO::JobFlag::Overwrite);
     connect(job, &KIO::CopyJob::result, [=](KJob *job) {
-        if (job->error())
-        {
+        if (job->error()) {
             job->uiDelegate()->showErrorMessage();
             job->kill();
 
@@ -242,18 +224,19 @@ void AppearanceSettings::installSkin()
             return;
         }
 
-        installSkin(static_cast<KIO::CopyJob*>(job)->destUrl());
+        installSkin(static_cast<KIO::CopyJob *>(job)->destUrl());
     });
 }
 
-void AppearanceSettings::installSkin(const QUrl& skinUrl)
+void AppearanceSettings::installSkin(const QUrl &skinUrl)
 {
     QUrl skinArchiveUrl = QUrl(skinUrl);
     skinArchiveUrl.setScheme(QStringLiteral("tar"));
 
-    KIO::ListJob* job = KIO::listRecursive(skinArchiveUrl, KIO::HideProgressInfo, false);
-    connect(job, &KIO::ListJob::entries, [=](KIO::Job* /* job */, const KIO::UDSEntryList& list) {
-        if (list.isEmpty()) return;
+    KIO::ListJob *job = KIO::listRecursive(skinArchiveUrl, KIO::HideProgressInfo, false);
+    connect(job, &KIO::ListJob::entries, [=](KIO::Job * /* job */, const KIO::UDSEntryList &list) {
+        if (list.isEmpty())
+            return;
 
         QListIterator<KIO::UDSEntry> i(list);
         while (i.hasNext())
@@ -268,7 +251,7 @@ void AppearanceSettings::installSkin(const QUrl& skinUrl)
     });
 }
 
-bool AppearanceSettings::validateSkin(const QString& skinId, bool kns)
+bool AppearanceSettings::validateSkin(const QString &skinId, bool kns)
 {
     QString dir = kns ? QStringLiteral("kns_skins/") : QStringLiteral("skins/");
 
@@ -282,53 +265,48 @@ void AppearanceSettings::checkForExistingSkin()
 {
     m_installSkinId = m_installSkinFileList.at(0);
 
-    QModelIndexList skins = m_skins->match(m_skins->index(0, 0), SkinId,
-        m_installSkinId, 1, Qt::MatchExactly | Qt::MatchWrap);
+    QModelIndexList skins = m_skins->match(m_skins->index(0, 0), SkinId, m_installSkinId, 1, Qt::MatchExactly | Qt::MatchWrap);
 
     int exists = skins.count();
 
-    foreach (const QModelIndex& skin, skins)
-    {
+    foreach (const QModelIndex &skin, skins) {
         if (m_skins->item(skin.row())->data(SkinInstalledWithKns).toBool())
             --exists;
     }
 
-    if (exists > 0)
-    {
+    if (exists > 0) {
         QString skinDir = skins.at(0).data(SkinDir).toString();
         QFile skin(skinDir + QStringLiteral("titles.skin"));
 
-        if (!skin.open(QIODevice::ReadWrite))
-        {
+        if (!skin.open(QIODevice::ReadWrite)) {
             failInstall(xi18nc("@info", "This skin appears to be already installed and you lack the required permissions to overwrite it."));
-        }
-        else
-        {
+        } else {
             skin.close();
 
             int remove = KMessageBox::warningContinueCancel(parentWidget(),
-                xi18nc("@info", "This skin appears to be already installed. Do you want to overwrite it?"),
-                xi18nc("@title:window", "Skin Already Exists"),
-                KGuiItem(xi18nc("@action:button", "Reinstall Skin")));
+                                                            xi18nc("@info", "This skin appears to be already installed. Do you want to overwrite it?"),
+                                                            xi18nc("@title:window", "Skin Already Exists"),
+                                                            KGuiItem(xi18nc("@action:button", "Reinstall Skin")));
 
             if (remove == KMessageBox::Continue)
-                removeSkin(skinDir, [=](){ installSkinArchive(); });
+                removeSkin(skinDir, [=]() {
+                    installSkinArchive();
+                });
             else
                 cleanupAfterInstall();
         }
-    }
-    else
+    } else
         installSkinArchive();
 }
 
-void AppearanceSettings::removeSkin(const QString& skinDir, std::function<void()> successCallback)
+void AppearanceSettings::removeSkin(const QString &skinDir, std::function<void()> successCallback)
 {
-    KIO::DeleteJob* job = KIO::del(QUrl::fromLocalFile(skinDir), KIO::HideProgressInfo);
-    connect(job, &KIO::DeleteJob::result, [=](KJob* deleteJob) {
+    KIO::DeleteJob *job = KIO::del(QUrl::fromLocalFile(skinDir), KIO::HideProgressInfo);
+    connect(job, &KIO::DeleteJob::result, [=](KJob *deleteJob) {
         if (deleteJob->error()) {
             KMessageBox::error(parentWidget(), deleteJob->errorString(), xi18nc("@title:Window", "Could Not Delete Skin"));
         } else if (successCallback) {
-           successCallback();
+            successCallback();
         }
     });
 }
@@ -337,32 +315,27 @@ void AppearanceSettings::installSkinArchive()
 {
     KTar skinArchive(m_installSkinFile.fileName());
 
-    if (skinArchive.open(QIODevice::ReadOnly))
-    {
-        const KArchiveDirectory* skinDir = skinArchive.directory();
+    if (skinArchive.open(QIODevice::ReadOnly)) {
+        const KArchiveDirectory *skinDir = skinArchive.directory();
         skinDir->copyTo(m_localSkinsDir);
         skinArchive.close();
 
-        if (validateSkin(m_installSkinId, false))
-        {
+        if (validateSkin(m_installSkinId, false)) {
             populateSkinList();
 
             if (Settings::skin() == m_installSkinId)
-                emit settingsChanged();
+                Q_EMIT settingsChanged();
 
             cleanupAfterInstall();
-        }
-        else
-        {
+        } else {
             removeSkin(m_localSkinsDir + m_installSkinId);
             failInstall(xi18nc("@info", "Unable to locate required files in the skin archive.<nl/><nl/>The archive appears to be invalid."));
         }
-    }
-    else
+    } else
         failInstall(xi18nc("@info", "The skin archive file could not be opened."));
 }
 
-void AppearanceSettings::failInstall(const QString& error)
+void AppearanceSettings::failInstall(const QString &error)
 {
     KMessageBox::error(parentWidget(), error, xi18nc("@title:window", "Cannot Install Skin"));
 
@@ -374,8 +347,7 @@ void AppearanceSettings::cleanupAfterInstall()
     m_installSkinId.clear();
     m_installSkinFileList.clear();
 
-    if (m_installSkinFile.exists())
-    {
+    if (m_installSkinFile.exists()) {
         m_installSkinFile.close();
         m_installSkinFile.remove();
     }
@@ -383,63 +355,44 @@ void AppearanceSettings::cleanupAfterInstall()
 
 void AppearanceSettings::updateRemoveSkinButton()
 {
-    if (m_skins->rowCount() <= 1)
-    {
+    if (m_skins->rowCount() <= 1) {
         removeButton->setEnabled(false);
         return;
     }
 
-    QString skinDir;
-
-    QVariant value = skinList->currentIndex().data(SkinDir);
-    if (value.isValid())
-        skinDir = value.toString();
-
-    value = skinList->currentIndex().data(SkinInstalledWithKns);
-    bool isKnsSkin = value.toBool();
-
-    // We don't allow the user to remove the default skin
-    // or any skin which was installed through KNS3.
-    if (skinDir.isEmpty() || isKnsSkin)
-    {
-        removeButton->setEnabled(false);
-        return;
+    const QString skinDir = skinList->currentIndex().data(SkinDir).toString();
+    bool enabled = false;
+    if (!skinDir.isEmpty()) {
+        enabled == QFileInfo(skinDir + QStringLiteral("/title.skin")).isWritable();
     }
-
-    QFile titleSkin(skinDir + QStringLiteral("/title.skin"));
-
-    if (!titleSkin.open(QIODevice::ReadWrite))
-        removeButton->setEnabled(false);
-    else
-        removeButton->setEnabled(true);
-
-    titleSkin.close();
+    removeButton->setEnabled(enabled);
 }
 
 void AppearanceSettings::removeSelectedSkin()
 {
-    if (m_skins->rowCount() <= 1) return;
+    if (m_skins->rowCount() <= 1)
+        return;
 
     QString skinDir = skinList->currentIndex().data(SkinDir).toString();
     QString skinName = skinList->currentIndex().data(SkinName).toString();
     QString skinAuthor = skinList->currentIndex().data(SkinAuthor).toString();
 
-    if (skinDir.isEmpty()) return;
+    if (skinDir.isEmpty())
+        return;
 
     int remove = KMessageBox::warningContinueCancel(parentWidget(),
-            xi18nc("@info", "Do you want to remove \"%1\" by %2?", skinName, skinAuthor),
-            xi18nc("@title:window", "Remove Skin"),
-            KStandardGuiItem::del());
+                                                    xi18nc("@info", "Do you want to remove \"%1\" by %2?", skinName, skinAuthor),
+                                                    xi18nc("@title:window", "Remove Skin"),
+                                                    KStandardGuiItem::del());
 
     if (remove == KMessageBox::Continue)
-        removeSkin(skinDir, [=](){
+        removeSkin(skinDir, [=]() {
             QString skinId = skinList->currentIndex().data(SkinId).toString();
-            if (skinId == Settings::skin())
-            {
+            if (skinId == Settings::skin()) {
                 Settings::setSkin(QStringLiteral("default"));
                 Settings::setSkinInstalledWithKns(false);
                 Settings::self()->save();
-                emit settingsChanged();
+                Q_EMIT settingsChanged();
             }
 
             resetSelection();
@@ -447,15 +400,13 @@ void AppearanceSettings::removeSelectedSkin()
         });
 }
 
-QSet<QString> AppearanceSettings::extractKnsSkinIds(const QStringList& fileList)
+QSet<QString> AppearanceSettings::extractKnsSkinIds(const QStringList &fileList)
 {
     QSet<QString> skinIdList;
 
-    foreach (const QString& file, fileList)
-    {
+    foreach (const QString &file, fileList) {
         // We only care about files/directories which are subdirectories of our KNS skins dir.
-        if (file.startsWith(m_knsSkinDir, Qt::CaseInsensitive))
-        {
+        if (file.startsWith(m_knsSkinDir, Qt::CaseInsensitive)) {
             // Get the relative filename (this removes the KNS install dir from the filename).
             QString relativeName = QString(file).remove(m_knsSkinDir, Qt::CaseInsensitive);
 
@@ -463,8 +414,7 @@ QSet<QString> AppearanceSettings::extractKnsSkinIds(const QStringList& fileList)
             QString skinId = relativeName.section(QLatin1Char('/'), 0, 0, QString::SectionSkipEmpty);
 
             // Skip all other entries in the file list if we found what we were searching for.
-            if (!skinId.isEmpty())
-            {
+            if (!skinId.isEmpty()) {
                 // First remove all remaining slashes (as there could be leading or trailing ones).
                 skinId.remove(QStringLiteral("/"));
 
@@ -478,69 +428,81 @@ QSet<QString> AppearanceSettings::extractKnsSkinIds(const QStringList& fileList)
 
 void AppearanceSettings::getNewSkins()
 {
+#if KNEWSTUFF_VERSION < QT_VERSION_CHECK(5, 78, 0)
     QPointer<KNS3::DownloadDialog> dialog = new KNS3::DownloadDialog(m_knsConfigFileName, this);
-
     // Show the KNS dialog. NOTE: We are NOT supposed to check the dialog's result,
     // because the actions are asynchronous (items are installed or uninstalled,
     // regardless whether the dialog's result is Accepted or Rejected)!
     dialog->exec();
 
-    if (dialog.isNull())
-    {
+    if (dialog.isNull()) {
         return;
     }
+    const KNS3::Entry::List changedEntries = dialog->changedEntries();
+#else
+    QPointer<KNS3::QtQuickDialogWrapper> dialog = new KNS3::QtQuickDialogWrapper(m_knsConfigFileName, this);
+    const QList<KNSCore::EntryInternal> changedEntries = dialog->exec();
+#endif
 
-    if (!dialog->installedEntries().empty())
-    {
-        quint32 invalidEntryCount = 0;
-        QString invalidSkinText;
+    quint32 invalidEntryCount = 0;
+    QString invalidSkinText;
+    for (const auto &_entry : changedEntries) {
+        if (_entry.status() != KNS3::Entry::Installed) {
+            continue;
+        }
+#if KNEWSTUFF_VERSION < QT_VERSION_CHECK(5, 78, 0)
+        const KNSCore::EntryInternal entry = KNSCore::EntryInternal::fromEntry(_entry);
+#else
+        const KNSCore::EntryInternal &entry = _entry;
+#endif
+        bool isValid = true;
+        const QSet<QString> &skinIdList = extractKnsSkinIds(entry.installedFiles());
 
-        foreach (const KNS3::Entry &entry3, dialog->installedEntries())
-        {
-            KNSCore::EntryInternal entry = KNSCore::EntryInternal::fromEntry(entry3);
-            bool isValid = true;
-            const QSet<QString>& skinIdList = extractKnsSkinIds(entry.installedFiles());
-
-            // Validate all skin IDs as each archive can contain multiple skins.
-            foreach (const QString& skinId, skinIdList)
-            {
-                // Validate the current skin.
-                if (!validateSkin(skinId, true))
-                {
-                    isValid = false;
-                }
-            }
-
-            // We'll add an error message for the whole KNS entry if
-            // the current skin is marked as invalid.
-            // We should not do this per skin as the user does not know that
-            // there are more skins inside one archive.
-            if (!isValid)
-            {
-                invalidEntryCount++;
-
-                // The user needs to know the name of the skin which
-                // was removed.
-                invalidSkinText += QString(QStringLiteral("<li>%1</li>")).arg(entry.name());
-
-                // Then remove the skin.
-                m_knsDownloadManager->uninstallEntry(entry);
+        // Validate all skin IDs as each archive can contain multiple skins.
+        for (const QString &skinId : skinIdList) {
+            // Validate the current skin.
+            if (!validateSkin(skinId, true)) {
+                isValid = false;
             }
         }
 
-        // Are there any invalid entries?
-        if (invalidEntryCount > 0)
-        {
-            failInstall(xi18ncp("@info",
-                               "The following skin is missing required files. Thus it was removed:<ul>%2</ul>",
-                               "The following skins are missing required files. Thus they were removed:<ul>%2</ul>",
-                               invalidEntryCount,
-                               invalidSkinText));
+        // We'll add an error message for the whole KNS entry if
+        // the current skin is marked as invalid.
+        // We should not do this per skin as the user does not know that
+        // there are more skins inside one archive.
+        if (!isValid) {
+            invalidEntryCount++;
+
+            // The user needs to know the name of the skin which
+            // was removed.
+            invalidSkinText += QString(QStringLiteral("<li>%1</li>")).arg(entry.name());
+
+            // Then remove the skin.
+            const QStringList files = entry.installedFiles();
+            for (const QString &file : files) {
+                QFileInfo info(QString(file).remove(QStringLiteral("/*")));
+                if (!info.exists()) {
+                    continue;
+                }
+                if (info.isDir()) {
+                    QDir(info.absoluteFilePath()).removeRecursively();
+                } else {
+                    QFile::remove(info.absoluteFilePath());
+                }
+            }
         }
     }
 
-    if (!dialog->changedEntries().isEmpty())
-    {
+    // Are there any invalid entries?
+    if (invalidEntryCount > 0) {
+        failInstall(xi18ncp("@info",
+                            "The following skin is missing required files. Thus it was removed:<ul>%2</ul>",
+                            "The following skins are missing required files. Thus they were removed:<ul>%2</ul>",
+                            invalidEntryCount,
+                            invalidSkinText));
+    }
+
+    if (!changedEntries.isEmpty()) {
         // Reset the selection in case the currently selected
         // skin was removed.
         resetSelection();
