@@ -1,25 +1,10 @@
 /*
-  Copyright (C) 2008-2014 by Eike Hein <hein@kde.org>
-  Copyright (C) 2009 by Juan Carlos Torres <carlosdgtorres@gmail.com>
+  SPDX-FileCopyrightText: 2008-2014 Eike Hein <hein@kde.org>
+  SPDX-FileCopyrightText: 2009 Juan Carlos Torres <carlosdgtorres@gmail.com>
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License as
-  published by the Free Software Foundation; either version 2 of
-  the License or (at your option) version 3 or any later version
-  accepted by the membership of KDE e.V. (or its successor appro-
-  ved by the membership of KDE e.V.), which shall act as a proxy
-  defined in Section 14 of version 3 of the license.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program. If not, see https://www.gnu.org/licenses/.
+  SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-
 #include "sessionstack.h"
 #include "settings.h"
 #include "terminal.h"
@@ -27,15 +12,16 @@
 
 #include <config-yakuake.h>
 
-#include <KMessageBox>
 #include <KLocalizedString>
+#include <KMessageBox>
 #include <KNotification>
 
 #include <QDBusConnection>
 
 static bool show_disallow_certain_dbus_methods_message = true;
 
-SessionStack::SessionStack(QWidget* parent) : QStackedWidget(parent)
+SessionStack::SessionStack(QWidget *parent)
+    : QStackedWidget(parent)
 {
     QDBusConnection::sessionBus().registerObject(QStringLiteral("/yakuake/sessions"), this, QDBusConnection::ExportScriptableSlots);
 
@@ -51,17 +37,19 @@ SessionStack::~SessionStack()
 
 int SessionStack::addSessionImpl(Session::SessionType type)
 {
-    Session* currentSession  = m_sessions.value(activeSessionId());
-    Terminal* currentTerminal = currentSession ? currentSession->getTerminal(currentSession->activeTerminalId()) : nullptr;
+    Session *currentSession = m_sessions.value(activeSessionId());
+    Terminal *currentTerminal = currentSession ? currentSession->getTerminal(currentSession->activeTerminalId()) : nullptr;
     QString workingDir = currentTerminal ? currentTerminal->currentWorkingDirectory() : QString();
 
-    Session* session = new Session(workingDir, type, this);
+    Session *session = new Session(workingDir, type, this);
+    // clang-format off
     connect(session, SIGNAL(titleChanged(int,QString)), this, SIGNAL(titleChanged(int,QString)));
     connect(session, SIGNAL(terminalManuallyActivated(Terminal*)), this, SLOT(handleManualTerminalActivation(Terminal*)));
     connect(session, SIGNAL(keyboardInputBlocked(Terminal*)), m_visualEventOverlay, SLOT(indicateKeyboardInputBlocked(Terminal*)));
     connect(session, SIGNAL(activityDetected(Terminal*)), parentWidget(), SLOT(handleTerminalActivity(Terminal*)));
     connect(session, SIGNAL(silenceDetected(Terminal*)), parentWidget(), SLOT(handleTerminalSilence(Terminal*)));
     connect(parentWidget(), SIGNAL(windowClosed()), session, SLOT(reconnectMonitorActivitySignals()));
+    // clang-format on
     connect(session, SIGNAL(destroyed(int)), this, SLOT(cleanup(int)));
 
     addWidget(session->widget());
@@ -69,9 +57,9 @@ int SessionStack::addSessionImpl(Session::SessionType type)
     m_sessions.insert(session->id(), session);
 
     if (Settings::dynamicTabTitles())
-        emit sessionAdded(session->id(), session->title());
+        Q_EMIT sessionAdded(session->id(), session->title());
     else
-        emit sessionAdded(session->id(), QString());
+        Q_EMIT sessionAdded(session->id(), QString());
 
     return session->id();
 }
@@ -98,22 +86,21 @@ int SessionStack::addSessionQuad()
 
 void SessionStack::raiseSession(int sessionId)
 {
-    if (sessionId == -1 || !m_sessions.contains(sessionId)) return;
-    Session* session = m_sessions.value(sessionId);
+    if (sessionId == -1 || !m_sessions.contains(sessionId))
+        return;
+    Session *session = m_sessions.value(sessionId);
 
     if (!m_visualEventOverlay->isHidden())
         m_visualEventOverlay->hide();
 
-    if (m_activeSessionId != -1 && m_sessions.contains(m_activeSessionId))
-    {
-        Session* oldActiveSession = m_sessions.value(m_activeSessionId);
+    if (m_activeSessionId != -1 && m_sessions.contains(m_activeSessionId)) {
+        Session *oldActiveSession = m_sessions.value(m_activeSessionId);
 
         disconnect(oldActiveSession, SLOT(closeTerminal()));
         disconnect(oldActiveSession, SLOT(focusPreviousTerminal()));
         disconnect(oldActiveSession, SLOT(focusNextTerminal()));
         disconnect(oldActiveSession, SLOT(manageProfiles()));
-        disconnect(oldActiveSession, SIGNAL(titleChanged(QString)),
-            this, SIGNAL(activeTitleChanged(QString)));
+        disconnect(oldActiveSession, SIGNAL(titleChanged(QString)), this, SIGNAL(activeTitleChanged(QString)));
 
         oldActiveSession->reconnectMonitorActivitySignals();
     }
@@ -134,16 +121,19 @@ void SessionStack::raiseSession(int sessionId)
     connect(this, SIGNAL(manageProfiles()), session, SLOT(manageProfiles()));
     connect(session, SIGNAL(titleChanged(QString)), this, SIGNAL(activeTitleChanged(QString)));
 
-    emit sessionRaised(sessionId);
+    Q_EMIT sessionRaised(sessionId);
 
-    emit activeTitleChanged(session->title());
+    Q_EMIT activeTitleChanged(session->title());
 }
 
 void SessionStack::removeSession(int sessionId)
 {
-    if (sessionId == -1) sessionId = m_activeSessionId;
-    if (sessionId == -1) return;
-    if (!m_sessions.contains(sessionId)) return;
+    if (sessionId == -1)
+        sessionId = m_activeSessionId;
+    if (sessionId == -1)
+        return;
+    if (!m_sessions.contains(sessionId))
+        return;
 
     if (queryClose(sessionId, QueryCloseSession))
         m_sessions.value(sessionId)->deleteLater();
@@ -153,16 +143,15 @@ void SessionStack::removeTerminal(int terminalId)
 {
     int sessionId = sessionIdForTerminalId(terminalId);
 
-    if (terminalId == -1)
-    {
-        if (m_activeSessionId == -1) return;
-        if (!m_sessions.contains(m_activeSessionId)) return;
+    if (terminalId == -1) {
+        if (m_activeSessionId == -1)
+            return;
+        if (!m_sessions.contains(m_activeSessionId))
+            return;
 
         if (m_sessions.value(m_activeSessionId)->closable())
             m_sessions.value(m_activeSessionId)->closeTerminal();
-    }
-    else
-    {
+    } else {
         if (m_sessions.value(sessionId)->closable())
             m_sessions.value(sessionId)->closeTerminal(terminalId);
     }
@@ -170,27 +159,31 @@ void SessionStack::removeTerminal(int terminalId)
 
 void SessionStack::closeActiveTerminal(int sessionId)
 {
-    if (sessionId == -1) sessionId = m_activeSessionId;
-    if (sessionId == -1) return;
-    if (!m_sessions.contains(sessionId)) return;
+    if (sessionId == -1)
+        sessionId = m_activeSessionId;
+    if (sessionId == -1)
+        return;
+    if (!m_sessions.contains(sessionId))
+        return;
 
     if (queryClose(sessionId, QueryCloseTerminal))
         m_sessions.value(sessionId)->closeTerminal();
 }
 
-
 void SessionStack::cleanup(int sessionId)
 {
-    if (sessionId == m_activeSessionId) m_activeSessionId = -1;
+    if (sessionId == m_activeSessionId)
+        m_activeSessionId = -1;
 
     m_sessions.remove(sessionId);
 
-    emit sessionRemoved(sessionId);
+    Q_EMIT sessionRemoved(sessionId);
 }
 
 int SessionStack::activeTerminalId()
 {
-    if (!m_sessions.contains(m_activeSessionId)) return -1;
+    if (!m_sessions.contains(m_activeSessionId))
+        return -1;
 
     return m_sessions.value(m_activeSessionId)->activeTerminalId();
 }
@@ -212,10 +205,9 @@ const QString SessionStack::terminalIdList()
 {
     QStringList idList;
 
-    QHashIterator<int, Session*> it(m_sessions);
+    QHashIterator<int, Session *> it(m_sessions);
 
-    while (it.hasNext())
-    {
+    while (it.hasNext()) {
         it.next();
 
         idList << it.value()->terminalIdList();
@@ -226,7 +218,8 @@ const QString SessionStack::terminalIdList()
 
 const QString SessionStack::terminalIdsForSessionId(int sessionId)
 {
-    if (!m_sessions.contains(sessionId)) return QString::number(-1);
+    if (!m_sessions.contains(sessionId))
+        return QString::number(-1);
 
     return m_sessions.value(sessionId)->terminalIdList();
 }
@@ -235,14 +228,12 @@ int SessionStack::sessionIdForTerminalId(int terminalId)
 {
     int sessionId = -1;
 
-    QHashIterator<int, Session*> it(m_sessions);
+    QHashIterator<int, Session *> it(m_sessions);
 
-    while (it.hasNext())
-    {
+    while (it.hasNext()) {
         it.next();
 
-        if (it.value()->hasTerminal(terminalId))
-        {
+        if (it.value()->hasTerminal(terminalId)) {
             sessionId = it.key();
 
             break;
@@ -256,31 +247,35 @@ static void warnAboutDBus()
 {
 #if !defined(REMOVE_SENDTEXT_RUNCOMMAND_DBUS_METHODS)
     if (show_disallow_certain_dbus_methods_message) {
-        KNotification::event(KNotification::Warning, QStringLiteral("Yakuake D-Bus Warning"),
-            i18n("The D-Bus method runCommand was just used.  There are security concerns about allowing these methods to be public.  If desired, these methods can be changed to internal use only by re-compiling Yakuake. <p>This warning will only show once for this Yakuake instance.</p>"));
+        KNotification::event(
+            KNotification::Warning,
+            QStringLiteral("Yakuake D-Bus Warning"),
+            i18n("The D-Bus method runCommand was just used.  There are security concerns about allowing these methods to be public.  If desired, these "
+                 "methods can be changed to internal use only by re-compiling Yakuake. <p>This warning will only show once for this Yakuake instance.</p>"));
         show_disallow_certain_dbus_methods_message = false;
     }
 #endif
 }
 
-void SessionStack::runCommand(const QString& command)
+void SessionStack::runCommand(const QString &command)
 {
     warnAboutDBus();
 
-    if (m_activeSessionId == -1) return;
-    if (!m_sessions.contains(m_activeSessionId)) return;
+    if (m_activeSessionId == -1)
+        return;
+    if (!m_sessions.contains(m_activeSessionId))
+        return;
 
     m_sessions.value(m_activeSessionId)->runCommand(command);
 }
 
-void SessionStack::runCommandInTerminal(int terminalId, const QString& command)
+void SessionStack::runCommandInTerminal(int terminalId, const QString &command)
 {
     warnAboutDBus();
 
-    QHashIterator<int, Session*> it(m_sessions);
+    QHashIterator<int, Session *> it(m_sessions);
 
-    while (it.hasNext())
-    {
+    while (it.hasNext()) {
         it.next();
 
         it.value()->runCommand(command, terminalId);
@@ -289,28 +284,33 @@ void SessionStack::runCommandInTerminal(int terminalId, const QString& command)
 
 bool SessionStack::isSessionClosable(int sessionId)
 {
-    if (sessionId == -1) sessionId = m_activeSessionId;
-    if (sessionId == -1) return false;
-    if (!m_sessions.contains(sessionId)) return false;
+    if (sessionId == -1)
+        sessionId = m_activeSessionId;
+    if (sessionId == -1)
+        return false;
+    if (!m_sessions.contains(sessionId))
+        return false;
 
     return m_sessions.value(sessionId)->closable();
 }
 
 void SessionStack::setSessionClosable(int sessionId, bool closable)
 {
-    if (sessionId == -1) sessionId = m_activeSessionId;
-    if (sessionId == -1) return;
-    if (!m_sessions.contains(sessionId)) return;
+    if (sessionId == -1)
+        sessionId = m_activeSessionId;
+    if (sessionId == -1)
+        return;
+    if (!m_sessions.contains(sessionId))
+        return;
 
     m_sessions.value(sessionId)->setClosable(closable);
 }
 
 bool SessionStack::hasUnclosableSessions() const
 {
-    QHashIterator<int, Session*> it(m_sessions);
+    QHashIterator<int, Session *> it(m_sessions);
 
-    while (it.hasNext())
-    {
+    while (it.hasNext()) {
         it.next();
 
         if (!it.value()->closable())
@@ -322,23 +322,28 @@ bool SessionStack::hasUnclosableSessions() const
 
 bool SessionStack::isSessionKeyboardInputEnabled(int sessionId)
 {
-    if (sessionId == -1) sessionId = m_activeSessionId;
-    if (sessionId == -1) return false;
-    if (!m_sessions.contains(sessionId)) return false;
+    if (sessionId == -1)
+        sessionId = m_activeSessionId;
+    if (sessionId == -1)
+        return false;
+    if (!m_sessions.contains(sessionId))
+        return false;
 
     return m_sessions.value(sessionId)->keyboardInputEnabled();
 }
 
 void SessionStack::setSessionKeyboardInputEnabled(int sessionId, bool enabled)
 {
-    if (sessionId == -1) sessionId = m_activeSessionId;
-    if (sessionId == -1) return;
-    if (!m_sessions.contains(sessionId)) return;
+    if (sessionId == -1)
+        sessionId = m_activeSessionId;
+    if (sessionId == -1)
+        return;
+    if (!m_sessions.contains(sessionId))
+        return;
 
     m_sessions.value(sessionId)->setKeyboardInputEnabled(enabled);
 
-    if (sessionId == m_activeSessionId)
-    {
+    if (sessionId == m_activeSessionId) {
         if (enabled)
             m_visualEventOverlay->hide();
         else
@@ -349,8 +354,10 @@ void SessionStack::setSessionKeyboardInputEnabled(int sessionId, bool enabled)
 bool SessionStack::isTerminalKeyboardInputEnabled(int terminalId)
 {
     int sessionId = sessionIdForTerminalId(terminalId);
-    if (sessionId == -1) return false;
-    if (!m_sessions.contains(sessionId)) return false;
+    if (sessionId == -1)
+        return false;
+    if (!m_sessions.contains(sessionId))
+        return false;
 
     return m_sessions.value(sessionId)->keyboardInputEnabled(terminalId);
 }
@@ -358,13 +365,14 @@ bool SessionStack::isTerminalKeyboardInputEnabled(int terminalId)
 void SessionStack::setTerminalKeyboardInputEnabled(int terminalId, bool enabled)
 {
     int sessionId = sessionIdForTerminalId(terminalId);
-    if (sessionId == -1) return;
-    if (!m_sessions.contains(sessionId)) return;
+    if (sessionId == -1)
+        return;
+    if (!m_sessions.contains(sessionId))
+        return;
 
     m_sessions.value(sessionId)->setKeyboardInputEnabled(terminalId, enabled);
 
-    if (sessionId == m_activeSessionId)
-    {
+    if (sessionId == m_activeSessionId) {
         if (enabled)
             m_visualEventOverlay->hide();
         else
@@ -374,36 +382,48 @@ void SessionStack::setTerminalKeyboardInputEnabled(int terminalId, bool enabled)
 
 bool SessionStack::hasTerminalsWithKeyboardInputEnabled(int sessionId)
 {
-    if (sessionId == -1) sessionId = m_activeSessionId;
-    if (sessionId == -1) return false;
-    if (!m_sessions.contains(sessionId)) return false;
+    if (sessionId == -1)
+        sessionId = m_activeSessionId;
+    if (sessionId == -1)
+        return false;
+    if (!m_sessions.contains(sessionId))
+        return false;
 
     return m_sessions.value(sessionId)->hasTerminalsWithKeyboardInputEnabled();
 }
 
 bool SessionStack::hasTerminalsWithKeyboardInputDisabled(int sessionId)
 {
-    if (sessionId == -1) sessionId = m_activeSessionId;
-    if (sessionId == -1) return false;
-    if (!m_sessions.contains(sessionId)) return false;
+    if (sessionId == -1)
+        sessionId = m_activeSessionId;
+    if (sessionId == -1)
+        return false;
+    if (!m_sessions.contains(sessionId))
+        return false;
 
     return m_sessions.value(sessionId)->hasTerminalsWithKeyboardInputDisabled();
 }
 
 bool SessionStack::isSessionMonitorActivityEnabled(int sessionId)
 {
-    if (sessionId == -1) sessionId = m_activeSessionId;
-    if (sessionId == -1) return false;
-    if (!m_sessions.contains(sessionId)) return false;
+    if (sessionId == -1)
+        sessionId = m_activeSessionId;
+    if (sessionId == -1)
+        return false;
+    if (!m_sessions.contains(sessionId))
+        return false;
 
     return m_sessions.value(sessionId)->monitorActivityEnabled();
 }
 
 void SessionStack::setSessionMonitorActivityEnabled(int sessionId, bool enabled)
 {
-    if (sessionId == -1) sessionId = m_activeSessionId;
-    if (sessionId == -1) return;
-    if (!m_sessions.contains(sessionId)) return;
+    if (sessionId == -1)
+        sessionId = m_activeSessionId;
+    if (sessionId == -1)
+        return;
+    if (!m_sessions.contains(sessionId))
+        return;
 
     m_sessions.value(sessionId)->setMonitorActivityEnabled(enabled);
 }
@@ -411,8 +431,10 @@ void SessionStack::setSessionMonitorActivityEnabled(int sessionId, bool enabled)
 bool SessionStack::isTerminalMonitorActivityEnabled(int terminalId)
 {
     int sessionId = sessionIdForTerminalId(terminalId);
-    if (sessionId == -1) return false;
-    if (!m_sessions.contains(sessionId)) return false;
+    if (sessionId == -1)
+        return false;
+    if (!m_sessions.contains(sessionId))
+        return false;
 
     return m_sessions.value(sessionId)->monitorActivityEnabled(terminalId);
 }
@@ -420,44 +442,58 @@ bool SessionStack::isTerminalMonitorActivityEnabled(int terminalId)
 void SessionStack::setTerminalMonitorActivityEnabled(int terminalId, bool enabled)
 {
     int sessionId = sessionIdForTerminalId(terminalId);
-    if (sessionId == -1) return;
-    if (!m_sessions.contains(sessionId)) return;
+    if (sessionId == -1)
+        return;
+    if (!m_sessions.contains(sessionId))
+        return;
 
     m_sessions.value(sessionId)->setMonitorActivityEnabled(terminalId, enabled);
 }
 
 bool SessionStack::hasTerminalsWithMonitorActivityEnabled(int sessionId)
 {
-    if (sessionId == -1) sessionId = m_activeSessionId;
-    if (sessionId == -1) return false;
-    if (!m_sessions.contains(sessionId)) return false;
+    if (sessionId == -1)
+        sessionId = m_activeSessionId;
+    if (sessionId == -1)
+        return false;
+    if (!m_sessions.contains(sessionId))
+        return false;
 
     return m_sessions.value(sessionId)->hasTerminalsWithMonitorActivityEnabled();
 }
 
 bool SessionStack::hasTerminalsWithMonitorActivityDisabled(int sessionId)
 {
-    if (sessionId == -1) sessionId = m_activeSessionId;
-    if (sessionId == -1) return false;
-    if (!m_sessions.contains(sessionId)) return false;
+    if (sessionId == -1)
+        sessionId = m_activeSessionId;
+    if (sessionId == -1)
+        return false;
+    if (!m_sessions.contains(sessionId))
+        return false;
 
     return m_sessions.value(sessionId)->hasTerminalsWithMonitorActivityDisabled();
 }
 
 bool SessionStack::isSessionMonitorSilenceEnabled(int sessionId)
 {
-    if (sessionId == -1) sessionId = m_activeSessionId;
-    if (sessionId == -1) return false;
-    if (!m_sessions.contains(sessionId)) return false;
+    if (sessionId == -1)
+        sessionId = m_activeSessionId;
+    if (sessionId == -1)
+        return false;
+    if (!m_sessions.contains(sessionId))
+        return false;
 
     return m_sessions.value(sessionId)->monitorSilenceEnabled();
 }
 
 void SessionStack::setSessionMonitorSilenceEnabled(int sessionId, bool enabled)
 {
-    if (sessionId == -1) sessionId = m_activeSessionId;
-    if (sessionId == -1) return;
-    if (!m_sessions.contains(sessionId)) return;
+    if (sessionId == -1)
+        sessionId = m_activeSessionId;
+    if (sessionId == -1)
+        return;
+    if (!m_sessions.contains(sessionId))
+        return;
 
     m_sessions.value(sessionId)->setMonitorSilenceEnabled(enabled);
 }
@@ -465,8 +501,10 @@ void SessionStack::setSessionMonitorSilenceEnabled(int sessionId, bool enabled)
 bool SessionStack::isTerminalMonitorSilenceEnabled(int terminalId)
 {
     int sessionId = sessionIdForTerminalId(terminalId);
-    if (sessionId == -1) return false;
-    if (!m_sessions.contains(sessionId)) return false;
+    if (sessionId == -1)
+        return false;
+    if (!m_sessions.contains(sessionId))
+        return false;
 
     return m_sessions.value(sessionId)->monitorSilenceEnabled(terminalId);
 }
@@ -474,51 +512,66 @@ bool SessionStack::isTerminalMonitorSilenceEnabled(int terminalId)
 void SessionStack::setTerminalMonitorSilenceEnabled(int terminalId, bool enabled)
 {
     int sessionId = sessionIdForTerminalId(terminalId);
-    if (sessionId == -1) return;
-    if (!m_sessions.contains(sessionId)) return;
+    if (sessionId == -1)
+        return;
+    if (!m_sessions.contains(sessionId))
+        return;
 
     m_sessions.value(sessionId)->setMonitorSilenceEnabled(terminalId, enabled);
 }
 
 bool SessionStack::hasTerminalsWithMonitorSilenceEnabled(int sessionId)
 {
-    if (sessionId == -1) sessionId = m_activeSessionId;
-    if (sessionId == -1) return false;
-    if (!m_sessions.contains(sessionId)) return false;
+    if (sessionId == -1)
+        sessionId = m_activeSessionId;
+    if (sessionId == -1)
+        return false;
+    if (!m_sessions.contains(sessionId))
+        return false;
 
     return m_sessions.value(sessionId)->hasTerminalsWithMonitorSilenceEnabled();
 }
 
 bool SessionStack::hasTerminalsWithMonitorSilenceDisabled(int sessionId)
 {
-    if (sessionId == -1) sessionId = m_activeSessionId;
-    if (sessionId == -1) return false;
-    if (!m_sessions.contains(sessionId)) return false;
+    if (sessionId == -1)
+        sessionId = m_activeSessionId;
+    if (sessionId == -1)
+        return false;
+    if (!m_sessions.contains(sessionId))
+        return false;
 
     return m_sessions.value(sessionId)->hasTerminalsWithMonitorSilenceDisabled();
 }
 
 void SessionStack::editProfile(int sessionId)
 {
-    if (sessionId == -1) sessionId = m_activeSessionId;
-    if (sessionId == -1) return;
-    if (!m_sessions.contains(sessionId)) return;
+    if (sessionId == -1)
+        sessionId = m_activeSessionId;
+    if (sessionId == -1)
+        return;
+    if (!m_sessions.contains(sessionId))
+        return;
 
     m_sessions.value(sessionId)->editProfile();
 }
 
 int SessionStack::splitSessionLeftRight(int sessionId)
 {
-    if (sessionId == -1) return -1;
-    if (!m_sessions.contains(sessionId)) return -1;
+    if (sessionId == -1)
+        return -1;
+    if (!m_sessions.contains(sessionId))
+        return -1;
 
     return m_sessions.value(sessionId)->splitLeftRight();
 }
 
 int SessionStack::splitSessionTopBottom(int sessionId)
 {
-    if (sessionId == -1) return -1;
-    if (!m_sessions.contains(sessionId)) return -1;
+    if (sessionId == -1)
+        return -1;
+    if (!m_sessions.contains(sessionId))
+        return -1;
 
     return m_sessions.value(sessionId)->splitTopBottom();
 }
@@ -527,7 +580,8 @@ int SessionStack::splitTerminalLeftRight(int terminalId)
 {
     int sessionId = sessionIdForTerminalId(terminalId);
 
-    if (sessionId == -1) return -1;
+    if (sessionId == -1)
+        return -1;
 
     return m_sessions.value(sessionId)->splitLeftRight(terminalId);
 }
@@ -536,7 +590,8 @@ int SessionStack::splitTerminalTopBottom(int terminalId)
 {
     int sessionId = sessionIdForTerminalId(terminalId);
 
-    if (sessionId == -1) return -1;
+    if (sessionId == -1)
+        return -1;
 
     return m_sessions.value(sessionId)->splitTopBottom(terminalId);
 }
@@ -545,7 +600,8 @@ int SessionStack::tryGrowTerminalRight(int terminalId, uint pixels)
 {
     int sessionId = sessionIdForTerminalId(terminalId);
 
-    if (sessionId == -1) return -1;
+    if (sessionId == -1)
+        return -1;
 
     return m_sessions.value(sessionId)->tryGrowTerminal(terminalId, Session::Right, pixels);
 }
@@ -554,7 +610,8 @@ int SessionStack::tryGrowTerminalLeft(int terminalId, uint pixels)
 {
     int sessionId = sessionIdForTerminalId(terminalId);
 
-    if (sessionId == -1) return -1;
+    if (sessionId == -1)
+        return -1;
 
     return m_sessions.value(sessionId)->tryGrowTerminal(terminalId, Session::Left, pixels);
 }
@@ -563,7 +620,8 @@ int SessionStack::tryGrowTerminalTop(int terminalId, uint pixels)
 {
     int sessionId = sessionIdForTerminalId(terminalId);
 
-    if (sessionId == -1) return -1;
+    if (sessionId == -1)
+        return -1;
 
     return m_sessions.value(sessionId)->tryGrowTerminal(terminalId, Session::Up, pixels);
 }
@@ -572,7 +630,8 @@ int SessionStack::tryGrowTerminalBottom(int terminalId, uint pixels)
 {
     int sessionId = sessionIdForTerminalId(terminalId);
 
-    if (sessionId == -1) return -1;
+    if (sessionId == -1)
+        return -1;
 
     return m_sessions.value(sessionId)->tryGrowTerminal(terminalId, Session::Down, pixels);
 }
@@ -581,41 +640,40 @@ void SessionStack::emitTitles()
 {
     QString title;
 
-    QHashIterator<int, Session*> it(m_sessions);
+    QHashIterator<int, Session *> it(m_sessions);
 
-    while (it.hasNext())
-    {
+    while (it.hasNext()) {
         it.next();
 
         title = it.value()->title();
 
         if (!title.isEmpty())
-            emit titleChanged(it.value()->id(), title);
+            Q_EMIT titleChanged(it.value()->id(), title);
     }
 }
 
 bool SessionStack::requiresVisualEventOverlay()
 {
-    if (m_activeSessionId == -1) return false;
-    if (!m_sessions.contains(m_activeSessionId)) return false;
+    if (m_activeSessionId == -1)
+        return false;
+    if (!m_sessions.contains(m_activeSessionId))
+        return false;
 
     return m_sessions.value(m_activeSessionId)->hasTerminalsWithKeyboardInputDisabled();
 }
 
 void SessionStack::handleTerminalHighlightRequest(int terminalId)
 {
-    Terminal* terminal = nullptr;
+    Terminal *terminal = nullptr;
 
-    QHashIterator<int, Session*> it(m_sessions);
+    QHashIterator<int, Session *> it(m_sessions);
 
-    while (it.hasNext())
-    {
+    while (it.hasNext()) {
         it.next();
 
         terminal = it.value()->getTerminal(terminalId);
 
-        if (terminal && it.value()->id() == m_activeSessionId)
-        {
+        if (terminal && it.value()->id() == m_activeSessionId) {
             m_visualEventOverlay->highlightTerminal(terminal, true);
 
             break;
@@ -627,23 +685,26 @@ void SessionStack::showEvent(QShowEvent *event)
 {
     Q_UNUSED(event)
 
-    if (m_activeSessionId == -1) return;
-    if (!m_sessions.contains(m_activeSessionId)) return;
+    if (m_activeSessionId == -1)
+        return;
+    if (!m_sessions.contains(m_activeSessionId))
+        return;
 
     Terminal *terminal = m_sessions.value(m_activeSessionId)->getTerminal(activeTerminalId());
 
     if (terminal) {
-        QWidget* terminalWidget = terminal->terminalWidget();
-        if (terminalWidget) terminalWidget->setFocus();
+        QWidget *terminalWidget = terminal->terminalWidget();
+        if (terminalWidget)
+            terminalWidget->setFocus();
     }
 }
 
-void SessionStack::handleManualTerminalActivation(Terminal* terminal)
+void SessionStack::handleManualTerminalActivation(Terminal *terminal)
 {
     if (!Settings::terminalHighlightOnManualActivation())
         return;
 
-    Session* session = qobject_cast<Session*>(QObject::sender());
+    Session *session = qobject_cast<Session *>(QObject::sender());
 
     if (session->terminalCount() > 1)
         m_visualEventOverlay->highlightTerminal(terminal, false);
@@ -651,10 +712,10 @@ void SessionStack::handleManualTerminalActivation(Terminal* terminal)
 
 bool SessionStack::queryClose(int sessionId, QueryCloseType type)
 {
-    if (!m_sessions.contains(sessionId)) return false;
+    if (!m_sessions.contains(sessionId))
+        return false;
 
-    if (!m_sessions.value(sessionId)->closable())
-    {
+    if (!m_sessions.value(sessionId)->closable()) {
         QString closeQuestionIntro = xi18nc("@info", "<warning>You have locked this session to prevent accidental closing of terminals.</warning>");
         QString closeQuestion;
 
@@ -664,8 +725,10 @@ bool SessionStack::queryClose(int sessionId, QueryCloseType type)
             closeQuestion = xi18nc("@info", "Are you sure you want to close this terminal?");
 
         int result = KMessageBox::warningContinueCancel(this,
-            closeQuestionIntro + QStringLiteral("<br/><br/>") + closeQuestion,
-            xi18nc("@title:window", "Really Close?"), KStandardGuiItem::close(), KStandardGuiItem::cancel());
+                                                        closeQuestionIntro + QStringLiteral("<br/><br/>") + closeQuestion,
+                                                        xi18nc("@title:window", "Really Close?"),
+                                                        KStandardGuiItem::close(),
+                                                        KStandardGuiItem::cancel());
 
         if (result != KMessageBox::Continue)
             return false;
@@ -674,28 +737,23 @@ bool SessionStack::queryClose(int sessionId, QueryCloseType type)
     return true;
 }
 
-
-QList<KActionCollection*> SessionStack::getPartActionCollections()
+QList<KActionCollection *> SessionStack::getPartActionCollections()
 {
-    QList<KActionCollection*> actionCollections;
+    QList<KActionCollection *> actionCollections;
 
     const auto sessions = m_sessions.values();
-    for (auto* session : sessions) {
-
+    for (auto *session : sessions) {
         const auto terminalIds = session->terminalIdList().split(QStringLiteral(","));
 
-        for (const auto& terminalID : terminalIds) {
-
+        for (const auto &terminalID : terminalIds) {
             auto *terminal = session->getTerminal(terminalID.toInt());
             if (terminal) {
-                auto* collection = terminal->actionCollection();
+                auto *collection = terminal->actionCollection();
                 if (collection) {
                     actionCollections.append(collection);
                 }
             }
-
         }
-
     }
 
     return actionCollections;
